// MgAutoDelete.h
//-----------------------------------------------------------------------------
/*
    libMgTk - Mage Toolkit
    Copyright (C) 2001 Vitaliy Mikitchenko (Mage Productions)

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Vitaliy Mikitchenko
    webmaster@magep.cjb.net
*/
#ifndef MGAUTODELETE_H
#define MGAUTODELETE_H

/*! This is a class that automatically deletes the object associated with it
	when the stack unwinds. Therefore, it must be allocated on the stack and
	it must take an object that is a pointer!
*/
template <class type>
class MgDelete
{
public:
	/*! Constructor. Pass the object to delete. */
	MgDelete(type a) { fObject = a; fFree = true; }
	/*! Default constructor. Does nothing. */
	MgDelete() { fObject = NULL; fFree = false; }
	/*! Deletes the object if you have not told it to do otherwise. */
	~MgDelete() { if (fFree) delete fObject; }
	
	/*! Call this if you do not want to free the object. */
	void DoNotDelete() { fFree = false; }

	/*! If you used the default constructor, this operator sets the object to
		delete.
	*/
	void operator=(type a) { fObject = a; fFree = true; }
	
private:
	type fObject;
	bool fFree;
};

/*! This class deletes a pointer to an array.
	
	Example:
	
		char * a = new char[20];
		MgDeleteArray<char *> da(a);
	
	You must obey the same rules as in MgDelete.
*/
template <class type>
class MgDeleteArray
{
public:
	/*! Constructor. Pass the pointer to an array to delete. */
	MgDeleteArray(type a) { fObject = a; fFree = true; }
	/*! Defaault constructor. Does nothing. */
	MgDeleteArray() { fObject = NULL; fFree = false; }
	/*! Destructor. Deletes the pointer to an array. */
	MgDeleteArray() { if (fFree) delete [] fObject; }
	
	/*! Call this to not delete the associated object when the stack unwinds. */
	void DoNotDelete() { fFree = false; }
	
	/*! If you used the default constructor, use this to set the object to delete. */
	void operator=(type a) { fObject = a; fFree = true; }

private:
	type fObject;
	bool fFree;
};

#endif

