// MgBaseNet.h
//-----------------------------------------------------------------------------
/*
    libMgTk - Mage Toolkit
    Copyright (C) 2001 Vitaliy Mikitchenko (Mage Productions)

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Vitaliy Mikitchenko
    webmaster@magep.cjb.net
*/

#ifndef MGBASENET_H
#define MGBASENET_H

#include <SDL_types.h>

/*! \file MgBaseNet.h
	Contains some basic net classes.
*/

/*!	IP address class. */
class MgNetIPAddress
{
public:
	Uint32 host;	//! 32-bit IPv4 host address
	Uint32 port;	//! 16-bit protocol port
};

/*! TCP socket class. */
class MgNetTCPSocket;

/*! UDP socket class */
class MgNetUDPSocket;

/*! UPD packet class. */
class MgNetUDPPacket
{
public:
	int channel;				//! The src/dst channel of the packet.
	Uint8 * data;				//! The packet data.
	int len;					//! The length of the packet data.
	int maxlen;					//! The size of the data buffer.
	int status;					//! The staus after sending.
	MgNetIPAddress address;	//! The src/dst address of an incoming/outgoing packet.
};

/*! Socket set class */
class MgNetSocketSet;

/*! Any network socket can be safely cast to this socket type. */
class MgNetGenericSocket
{
public:
	int ready;
};

#endif

