// MgColor.h
//-----------------------------------------------------------------------------
/*
    libMgTk - Mage Toolkit
    Copyright (C) 2001 Vitaliy Mikitchenko (Mage Productions)

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Vitaliy Mikitchenko
    webmaster@magep.cjb.net
*/

#ifndef MGCOLOR_H
#define MGCOLOR_H

#include <SDL_video.h>

#include "MgBeginCode.h"

/*!\file MgColor.h
	Contains the MgColor class.
*/

/*!
	This class is here to automate using colors in libMgTk.
*/
class MGDLL MgColor
{
public:
	//! Constructor
	MgColor();
	//! Constructor.
	MgColor(Uint8 r, Uint8 g, Uint8 b, Uint8 a = 255);
	//! Constructor.
	MgColor(const SDL_Color & color);
	//! Constructor.
	MgColor(const MgColor & color);
	//! Destructor.
	~MgColor();
	
	void PrintToStream();
	
	//! SDL_Color operator
	operator SDL_Color () const
	{
		SDL_Color col;
		col.r = red; col.g = green; col.b = blue;
		return col;
	}
	
	//@{
	//! Returns true if the the passed color is equal to this object.
	bool operator==(const MgColor & rhs) const
	{
		return rhs.red == red && rhs.green == green &&
				rhs.blue == blue && rhs.alpha == alpha;
	}
	bool operator==(const SDL_Color & rhs) const
	{
		// no alpha in SDL's color
		return rhs.r == red && rhs.g == green && rhs.b == blue;
	}
	//@}
	
	//@{
	//! Returns true if the passed color is not equal to this object.
	bool operator!=(const MgColor & rhs) const
	{
		return rhs.red != red || rhs.green != green ||
				rhs.blue != blue || rhs.alpha != alpha;
	}
	bool operator!=(const SDL_Color & rhs) const
	{
		return rhs.r != red || rhs.g != green || rhs.b != blue;
	}
	//@}
	
	//! operator() that sets all the components in one go.
	void operator()(Uint8 r, Uint8 g, Uint8 b, Uint8 a = 255)
	{
		red = r; green = g; blue = b; alpha = a;
	}
	
	//! The red, green, blue and alpha components of the class.
	Uint8 red, green, blue, alpha;
};

#include "MgEndCode.h"

#endif

