// MgFont.h
//-----------------------------------------------------------------------------
/*
    libMgTk - Mage Toolkit
    Copyright (C) 2001 Vitaliy Mikitchenko (Mage Productions)

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Vitaliy Mikitchenko
    webmaster@magep.cjb.net
*/

#ifndef MGFONT_H
#define MGFONT_H

/*! \file MgFont.h
	Conains the MgFont class.
*/

#include "MgImage.h"

#include "MgBeginCode.h"

/*!
	This font class uses Karl Bartel's variable width fonts.
	It was created using the source from SFont. It was modified
	to work with libMgTk.
*/
class MGDLL MgFont : public MgImage
{
public:
	//! Constructor.
	MgFont(const char * file);
	//! Makes a duplicate copy of the surface and uses it as the font.
	MgFont(MgSurface * surface);
	//! Destructor.
	virtual ~MgFont();
	
	//! Draws some text.
	void DrawText(MgSurface * dst, int x, int y, const char * text);
	//! Change the color of the text
	void Colorize(MgColor newColor);
	
	//! Yes, you can reuse the new version of the font.
	virtual bool Load(const char * file);
	
	//! Get the height of the font.
	int Height();
	//! Get the length of a string.
	int Length(const char * text);
	//! Get some input from the user.
	void Input(MgSurface * dst, int x, int y, int pixelWidth, char *& text, int & textLength);
	//! Centers the string across the 'x' coord.
	void XCentered(MgSurface * dst, int x, int y, const char * text);
	//! Centers the string across the 'y' coord.
	void YCentered(MgSurface * dst, int x, int y, const char * text);
	//! Centers the string across the 'x' and 'y' coords.
	void Centered(MgSurface * dst, int x, int y, const char * text);

private:
	int fHeight;
	int * fCharPos;
	
	void InitFont();
};

#include "MgEndCode.h"
	
#endif

