// MgMutex.h
//-----------------------------------------------------------------------------
/*
    libMgTk - Mage Toolkit
    Copyright (C) 2001 Vitaliy Mikitchenko (Mage Productions)

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Vitaliy Mikitchenko
    webmaster@magep.cjb.net
*/

#ifndef MGMUTEX_H
#define MGMUTEX_H

#include <SDL_mutex.h>

/*! \file MgMutex.h
	This file includes all the mutex, semaphore and condition classes.
*/

#include "MgBeginCode.h"

/*!
	This is the mutex locking class. It provides a simple way to synchronize multiple threads
*/ 
class MGDLL MgMutex
{
public:
	//! Constructor.
	MgMutex();
	//! Destructor.
	~MgMutex();
	
	//! Locks the mutex.
	bool Lock();
	//! Unlocks the mutex.
	bool Unlock();
	
	//! SDL_mutex * operator.
	operator SDL_mutex *() const { return fMutex; }
	//! Returns the SDL_mutex *.
	SDL_mutex * Mutex() const { return fMutex; }
	
private:
	SDL_mutex * fMutex;
};

/*!
	This is the semaphore class.
*/
class MGDLL MgSemaphore
{
public:
	//! Constructor.
	MgSemaphore(Uint32 startVal);
	//! Destructor.
	~MgSemaphore();
	
	//! Locks the semaphore.
	bool Lock();
	//! Locks only if a wait will not occur.
	bool TryLock();
	//! Locks with a timeout.
	bool Lock(Uint32 ms);
	//! Unlocks the semaphore.
	bool Unlock();
	
	//! Get the current count of the semaphore
	Uint32 Value();
	
	//! SDL_semaphore * operator.
	operator SDL_semaphore *() const { return fSem; }
	//! Returns the SDL_semaphore.
	SDL_semaphore * Semaphore() const { return fSem; }
	
private:
	SDL_semaphore * fSem;
};

/*!
	This is the condition class.
*/
class MGDLL MgCond
{
public:
	//! Constructor.
	MgCond();
	//! Destructor.
	~MgCond();
	
	//! Restart one thread that is waiting on this condition.
	bool Signal();
	//! Restart all threads waiting on this condition.
	bool Broadcast();
	//! Wait on this condition.
	bool Wait(MgMutex & mutex);
	//! Wait with a timeout on this condition.
	bool Wait(MgMutex & mutex, Uint32 ms);
	
	//! SDL_cond * operator.
	operator SDL_cond *() const { return fCond; }
	//! Returns the SDL_cond *
	SDL_cond * Cond() const { return fCond; }

private:
	SDL_cond * fCond;
};

#include "MgEndCode.h"

#endif

