// MgRect.h
//-----------------------------------------------------------------------------
/*
    libMgTk - Mage Toolkit
    Copyright (C) 2001 Vitaliy Mikitchenko (Mage Productions)

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Vitaliy Mikitchenko
    webmaster@magep.cjb.net
*/

#ifndef MGRECT_H
#define MGRECT_H

/*! \file MgRect.h
	Contains the MgRect class.
*/

#include "MgPoint.h"

#include <SDL_video.h>	// for SDL_Rect

#include "MgBeginCode.h"

/*!
	Simple rectangle class.
*/
class MGDLL MgRect
{
public:
	//! Constructor.
	MgRect(int _left = 0, int _top = 0, int _right = 0, int _bottom = 0);
	//! Constructor.
	MgRect(const SDL_Rect & rect);
	//! Constructor.
	MgRect(const MgRect & rect);
	//! Destructor.
	~MgRect();
	
	//@{
	//! Returns the respective point.
	MgPoint LeftTop() const;
	MgPoint LeftBottom() const;
	MgPoint RightTop() const;
	MgPoint RightBottom() const;
	//@}
	
	//! Width of the rect.
	int Width() const;
	//! Height of the rect.
	int Height() const;
	
	//! Inset the points by 'x' and 'y'.
	void InsetBy(int x, int y);
	
	//! Set the coords in one big go.
	void SetTo(int left, int top, int right, int bottom);
	
	//@{
	//! Returns true if the rects are equal.
	bool operator==(const SDL_Rect & rhs) const
	{
		return rhs.x == left && rhs.y == top && (rhs.x + rhs.w - 1) == right &&
				(rhs.y + rhs.h - 1) == bottom;
	}
	bool operator==(const MgRect & rhs) const
	{
		return rhs.left == left && rhs.top == top && rhs.right == right &&
				rhs.bottom == bottom;
	}
	//@}
	
	//! SDL_Rect operator.
	operator SDL_Rect() const
	{
		SDL_Rect rct;
		rct.x = left; rct.y = top; rct.w = Width(); rct.h = Height();
		return rct;
	}
	
	//@{
	//! Returns true if the rects are not equal.
	bool operator!=(const SDL_Rect & rhs) const
	{
		return rhs.x != left || rhs.y != top || (rhs.x + rhs.w - 1) != right ||
				(rhs.y + rhs.h - 1) != bottom;
	}
	bool operator!=(const MgRect & rhs) const
	{
		return rhs.left != left || rhs.top != top || rhs.right != right ||
				rhs.bottom != bottom;
	}
	//@}
	
	//! The position vars.
	int left, right, top, bottom;
};

#include "MgEndCode.h"

#endif

