// MgTimerSystem.h
//-----------------------------------------------------------------------------
/*
    libMgTk - Mage Toolkit
    Copyright (C) 2001 Vitaliy Mikitchenko (Mage Productions)

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Vitaliy Mikitchenko
    webmaster@magep.cjb.net
*/

#ifndef MGTIMERSYSTEM_H
#define MGTIMERSYSTEM_H

/*! \file MgTimerSystem.h
	Includes the MgTimerSystem class used for timer initialization.
*/

#include <SDL_timer.h>

#include "MgSubSystem.h"

#include "MgBeginCode.h"

class MgTimer;

/*! The timer sub system. You can use this to add MgTimer's to be run.
	To use this, you must pass MG_TIMER as one of the flags to MGTK_MAIN().
*/
class MGDLL MgTimerSystem : public MgSubSystem
{
public:
	//! Constructor. Does nothing.
	MgTimerSystem();
	//! Destructor. Does nothing.
	virtual ~MgTimerSystem();
	
	virtual bool IsRunning() const;
	virtual bool Init();
	virtual void Quit();
	
	//! Add a timer.
	bool AddTimer(MgTimer * timer);
	//! Remove the timer.
	bool RemoveTimer(MgTimer * timer);

private:
	static Uint32 TimerCallback(Uint32 interal, void * timer);
};
	
#include "MgEndCode.h"

#endif

