// MgVersion.h
//-----------------------------------------------------------------------------
/*
    libMgTk - Mage Toolkit
    Copyright (C) 2001 Vitaliy Mikitchenko (Mage Productions)

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Vitaliy Mikitchenko
    webmaster@magep.cjb.net
*/

#ifndef MGVERSION_H
#define MGVERSION_H

/*! \file MgVersion.h
	Contains the version class.
*/

#include <SDL_types.h>

#include "MgBeginCode.h"


//@{
//! Version constant.
const Uint8 MG_MAJOR_VERSION = 2;
const Uint8 MG_MINOR_VERSION = 0;
const Uint8 MG_PATCH_VERSION = 0;
//@}

/*! This class is used for version control in libMgTk */
class MGDLL MgVersion
{
public:
	//! Constructor.
	MgVersion(Uint8 m = MG_MAJOR_VERSION, Uint8 n = MG_MINOR_VERSION,
				Uint8 p = MG_PATCH_VERSION);
	//! Destructor.
	~MgVersion();
	
	//@{
	//! Return the related value.
	Uint8 Major() const;
	Uint8 Minor() const;
	Uint8 Patch() const;
	//@}
	
	//! \return A formatted string containing the version.
	const char * VersionString() const;
	
	//! \return An integer value of the verison.
	Uint32 VersionNum() const;
	
	//! Get a pointer to the MgVersion that was linked in during build time.
	static MgVersion * Linked();
	
private:
	Uint8 fMajor, fMinor, fPatch;
	char fVer[15];
};

#include "MgEndCode.h"

#endif

