// MgVertex.h
//-----------------------------------------------------------------------------
/*
    libMgTk - Mage Toolkit
    Copyright (C) 2001 Vitaliy Mikitchenko (Mage Productions)

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Vitaliy Mikitchenko
    webmaster@magep.cjb.net
*/

#ifndef MGVERTEX_H
#define MGVERTEX_H

/*! \file MgVertex.h
	Contains the template class MgVertex. As well as several pregenerated versions.
*/

#include "MgColor.h"

#include "MgBeginCode.h"

/*! This class is used by MgSurface for drawing polygons. */
template <class type, class color>
class MgVertex
{
public:
	/*! Default constructor. Does nothing. If you use this version, be
		aware that the variables in the object have not been initialized.
	*/
	MgVertex();
	/*! Creates the vertex from the specified values. */
	MgVertex(type x, type y, color c);
	/*! Destructor. Does nothing. */
	~MgVertex();
	
	/*! These are the x and y coordinates of the vertex. */
	type x, y;
	/*! This is the color of the vertex. */
	color c;
};

/*! "int" version of MgVertex */
typedef MgVertex<int, MgColor> MgIVertex;
/*! "float" version of MgVertex */
typedef MgVertex<float, MgColor> MgFVertex;

#include "MgEndCode.h"



/* ===================================================================== */

template<class type, class color>
MgVertex<type, color>::MgVertex()
{
}

template<class type, class color>
MgVertex<type, color>::MgVertex(type x, type y, color c)
{
	this->x = x; this->y = y; this->c = c;
}

template<class type, class color>
MgVertex<type, color>::~MgVertex()
{
}


#endif

